@@ -100,8 +100,15 @@
                 type       => 'leaf',
                 value_type => 'uniline',
             },
+
+            rw_config => {
+                type              => 'node',
+                config_class_name => 'Itself::ConfigRead',
+            },
+
             'read_config' => {
                 type  => 'list',
+                status => 'deprecated',
                 cargo => {
                     type              => 'node',
                     config_class_name => 'Itself::ConfigRead',
@@ -110,6 +117,7 @@
 
             'write_config' => {
                 type  => 'list',
+                status => 'deprecated',
                 cargo => {
                     type              => 'node',
                     config_class_name => 'Itself::ConfigWrite',
@@ -132,8 +140,9 @@
             . "By default, included elements are placed before all other elements.",
             include_backend => "Include the read/write specification of another class into this class.",
             class_description => "Explain the purpose of this configuration class. This description is re-used to generate the documentation of your configuration class. You can use pod markup to format your description. See L<perlpod> for details.",
-            read_config => "Specify the Perl class(es) and function(s) used to read configuration data. The specified functions are tried in sequence to get configuration data. ",
-            write_config => "Specify the Perl class and function used to write configuration data.",
+            rw_config => "Specify the backend used to read and write configuration data. See L<Config::Model::BackendMgr> for details",
+            read_config => "Deprecated - specify the Perl class(es) and function(s) used to read configuration data. The specified functions are tried in sequence to get configuration data. ",
+            write_config => "Deprecated - Specify the Perl class and function used to write configuration data.",
             generated_by => "When set, this class was generated by some program. You should not edit "
                 ."this class as your modifications may be clobbered later on when the class is regenerated.",
             accept => "Specifies names of the elements this configuration class accepts as valid. "
@@ -147,7 +156,7 @@
     ],
 
     [
-        name => 'Itself::ConfigWR::DefaultLayer',
+        name => 'Itself::ConfigReadWrite::DefaultLayer',
 
         'element'     => [
             'config_dir' => {
@@ -185,35 +194,28 @@
     ],
 
     [
-        name => "Itself::ConfigWR",
-        include => "Itself::ConfigWR::DefaultLayer",
+        name => "Itself::ConfigReadWrite",
+        include => "Itself::ConfigReadWrite::DefaultLayer",
         include_after => 'backend',
 
         'element' => [
 
-            'syntax' => {
-                type       => 'leaf',
-                value_type => 'enum',
-                choice     => [qw/cds perl ini custom/],
-                status     => 'deprecated',
-                description => 'Deprecated parameter that specified the file syntax to store permanently configuration data. Replaced by "backend"',
-            },
-
             'backend' => {
                 type         => 'leaf',
                 class        => 'Config::Model::Itself::BackendDetector',
                 value_type   => 'enum',
                 choice       => [qw/cds_file perl_file custom/],
+                warn_if_match => {
+                    '^custom$' => {
+                        msg => "custom backend are deprecated"
+                    }
+                },
                 replace   => {
                     perl => 'perl_file',
                     ini  => 'IniFile',
                     ini_file  => 'IniFile',
                     cds  => 'cds_file',
                 },
-                migrate_from => {
-                    formula   => '$old',
-                    variables => { old => '- syntax' },
-                },
                 description => 'specifies the backend to store permanently configuration data.',
                 help => {
                     cds_file => "file with config data string. This is Config::Model own serialisation format, designed to be compact and readable. Configuration filename is made with instance name",
@@ -221,12 +223,19 @@
 "Ini file format. Beware that the structure of your model must match the limitations of the INI file format, i.e only a 2 levels hierarchy. Configuration filename is made with instance name",
                     perl_file =>
 "file with a perl data structure. Configuration filename is made with instance name",
-                    custom =>
-"Custom format. You must specify your own class and method to perform the read or write function. See Config::Model::AutoRead doc for more details",
+                    custom => "deprecated",
                }
             },
 
-           yaml_class => {
+            'auto_create' => {
+                type             => 'leaf',
+                value_type       => 'boolean',
+                level            => 'normal',
+                upstream_default => 0,
+                summary          => 'Creates configuration files as needed',
+            },
+
+            yaml_class => {
                 type             => 'leaf',
                 value_type       => 'uniline',
                 level            => 'hidden',
@@ -252,7 +261,7 @@
 
             default_layer => {
                 type => 'node',
-                config_class_name => 'Itself::ConfigWR::DefaultLayer',
+                config_class_name => 'Itself::ConfigReadWrite::DefaultLayer',
                 summary => q!How to find default values in a global config file!,
                 description => q!Specifies where to find a global configuration file that !
                     .q!specifies default values. For instance, this is used by OpenSSH to !
@@ -443,7 +452,7 @@
 
     [
         name    => 'Itself::ConfigRead',
-        include => "Itself::ConfigWR",
+        include => "Itself::ConfigReadWrite",
 
         'element' => [
             'function' => {
@@ -460,34 +469,12 @@
                     ],
                 }
             },
-
-            'auto_create' => {
-                type             => 'leaf',
-                value_type       => 'boolean',
-                level            => 'normal',
-                upstream_default => 0,
-                summary          => 'Creates configuration files as needed',
-                migrate_from     => {
-                    formula   => '$old',
-                    variables => { old => '- allow_empty' },
-                },
-            },
-
-            'allow_empty' => {
-                type             => 'leaf',
-                value_type       => 'boolean',
-                level            => 'normal',
-                status           => 'deprecated',
-                upstream_default => 0,
-                summary          => 'deprecated in favor of auto_create',
-            },
-
         ],
     ],
 
     [
         name    => 'Itself::ConfigWrite',
-        include => "Itself::ConfigWR",
+        include => "Itself::ConfigReadWrite",
 
         'element' => [
             'function' => {
@@ -504,16 +491,6 @@
                     ],
                 }
             },
-
-            # move to ConfigRW when removing legacy allow_empty
-            'auto_create' => {
-                type             => 'leaf',
-                value_type       => 'boolean',
-                level            => 'normal',
-                upstream_default => 0,
-                summary          => 'Creates configuration files as needed',
-            },
-
         ],
     ],
     [
